# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

#' Add an accepted parameter vector to the matrix detailing the closest fits
#' 
#' Each time a proposed parameter vector is accepted in the Random-Walk 
#' Metropolis Markov chain Monte Carlo algorithm, we ascertain the average
#' relative error to the experimental data set. If the error is less than one
#' of the vectors in the matrix, then the newly accepted parameter vector
#' replaces the vector in the matrix that produces the worst fit to data.
#'
#' @param current_mat A matrix of the accepted parameter vectors that
#'   achieve the best fits to experimental data in the algorithm so far.
#' @param n_row The number of parameter vectors that we save in the matrix.
#' @param ave_error The average relative error between the experimental data
#'   and the predicted stresses found with the accepted parameter vector.
#' @param iter An integer, the iteration in the algorithm that the parameter
#'   vector was accepted.
#' @param param_vec The accepted parameter vector.
#'
#' @return A matrix of the transformed parameter vectors that have been
#'   accepted and produced the best n_row fits to data so far in the algorithm.
rcpp_alter_closest_fits_mat <- function(current_mat, n_row, ave_error, iter, param_vec) {
    .Call(`_TendonMCMCSampling_rcpp_alter_closest_fits_mat`, current_mat, n_row, ave_error, iter, param_vec)
}

#' Find the average relative error between experimental and predicted stresses
#' 
#' This function calculates the average relative error between the experimental
#' data and the stresses predicted by the model for a given parameter vector.
#' For each experimental data set, the first stretch ratio measured is one, 
#' which gives a stress of zero. By construction of the model, the stress when 
#' the stretch ratio is one is zero. Therefore, we do not include the first 
#' term of the experimental or predicted stresses for this calculation.
#'
#' @param expt_data The experimental stresses we fit to.
#' @param prop_sim_data The proposed predicted stresses.
#'
#' @return
#' A double with the average relative error between the experimental stresses
#' and the predicted stresses.
rcpp_calc_ave_rel_err <- function(expt_data, prop_sim_data) {
    .Call(`_TendonMCMCSampling_rcpp_calc_ave_rel_err`, expt_data, prop_sim_data)
}

#' Compute logarithms of the model parameters (general tri. dist.)
#'
#' @param true_params A vector of, in order, (1-phi)*mu, phi*E, a-1, c-a, b-c.
#'
#' @return A vector with the logarithms of the model parameters.
#' @export
#'
#' @examples
#' rcpp_transf_true_params_gt(c(5, 600, 0.02, 0.08, 0.1))
rcpp_transf_true_params_gt <- function(true_params) {
    .Call(`_TendonMCMCSampling_rcpp_transf_true_params_gt`, true_params)
}

#' Compute the model parameters from their logarithms (general tri. dist.)
#'
#' @description
#' This function takes the logarithms of the five model parameters and creates
#' the following eight-element vector:
#' \itemize{
#' \item elements 1-5 contain the model parameters.
#' \item element 6 is the minimum recruitment stretch, or fibril length, a.
#' \item element 7 is the modal recruitment stretch, c.
#' \item element 8 is the maximum recruitment stretch, b.
#' }
#'
#' @param log_params A vector of, in order, nu, eta, tau, xi, chi.
#'
#' @return A vector containing eight elements that correspond to the five 
#'   fit parameters used in the RWM algorithm and the three distribution 
#'   parameters. (See the description above for more details.)
#' @export
#'
#' @examples
#' rcpp_transf_log_params_gt(c(1.61, 6.40, -3.91, -2.53, -2))
rcpp_transf_log_params_gt <- function(log_params) {
    .Call(`_TendonMCMCSampling_rcpp_transf_log_params_gt`, log_params)
}

#' Run RWM MCMC for the general triangular distribution
#'
#' @param stretch_expt The experimental stretch ratios.
#' @param stress_expt The experimentally observed engineering stress values,
#'   in megapascals.
#' @param starting_values The starting values of the parameters (1-phi)*mu, 
#'   phi*\emph{E}, \emph{a}-1, \emph{c}-\emph{a}, and \emph{b}-\emph{c}.
#' @param mean_vec A vector of means for the normal prior distributions of the
#'   transformed parameters.
#' @param sd_vec A vector of the standard deviations for the normal prior
#'   distributions of the transformed parameters.
#' @param param_num The number of fit parameters.
#' @param block_length An integer that represents the number of simulations
#'   that make up one block in the algorithm.
#' @param burn_in_length An integer that represents the number of simulations
#'   performed in the burn-in phase.
#' @param sim_num An integer that signifies the total number of simulations
#'   performed in the algorithm.
#' @param scale_cov_factor A double corresponding to the scale factor, beta,
#'   used in the adaptation of the proposal distribution covariance matrix.
#' @param accept_range A vector containing the minimum and maximum acceptance
#'   rates that are deemed to be acceptable for the efficient running of the 
#'   algorithm.
#' @param alpha_hyp A double corresponding to the parameter alpha of the 
#'   hyperprior.
#' @param beta_hyp A double corresponding to the parameter beta of the 
#'   hyperprior.
#' @param cov_calc_num An integer that defines how many simulations we take 
#'   the results from to adapt the covariance matrix of the proposal 
#'   distribution in the burn-in phase. We always take the most recent 
#'   \emph{N} simulations.
#' @param cov_calc_some A Boolean that determines whether we use the results
#'   of all previous simulations or not when adapting the covariance matrix of 
#'   the proposal distribution in the burn-in phase.
#' @param change_cov_mat A Boolean that determines whether we change the 
#'   covariance matrix of the proposal distribution or not.
#' @param print_iter An integer that determines after how many simulations do
#'   we print the simulation number to the console (to show the progress of 
#'   the algorithm).
#' @param fit_vec_num An integer that determines how many parameter vectors we
#'   collect in a matrix that collates the parameter vectors that achieve the
#'   best fit to data. The fit to data is determined in terms of the average
#'   relative error between the predicted stress and the experimental stress.
#'
#' @return
#' A list containing the following terms:
#' 
#'  \itemize{
#'    \item a matrix with the transformed parameters found in the algorithm.
#'    \item a matrix with the untransformed parameter found in the algorithm
#'      and the average relative error obtained at the end of each iteration
#'      of the algorithm.
#'    \item a vector of the acceptance ratios in each block.
#'    \item the covariance matrix of the proposal distribution.
#'    \item the matrix of closest fits achieved in the algorithm.
#' }
rcpp_gt_run_mcmc <- function(stretch_expt, stress_expt, starting_values, mean_vec, sd_vec, param_num, block_length, burn_in_length, sim_num, scale_cov_factor, accept_range, alpha_hyp, beta_hyp, cov_calc_num, cov_calc_some, change_cov_mat, print_iter, fit_vec_num) {
    .Call(`_TendonMCMCSampling_rcpp_gt_run_mcmc`, stretch_expt, stress_expt, starting_values, mean_vec, sd_vec, param_num, block_length, burn_in_length, sim_num, scale_cov_factor, accept_range, alpha_hyp, beta_hyp, cov_calc_num, cov_calc_some, change_cov_mat, print_iter, fit_vec_num)
}

#' First function for the stress on the collagen fibrils (general tri. dist.)
#'
#' @description
#' Function that calculates the contribution to the Cauchy stress from the
#' collagen fibrils when the stretch is greater than a and less than or equal
#' to the mode, c.
#'
#' @param eta The natural logarithm of phi*E, where E is the Young's modulus
#'   of the collagen fibrils and phi is the collagen fibril volume fraction.
#' @param tau The natural logarithm of a-1.
#' @param xi The natural logarithm of c-a.
#' @param chi The natural logarithm of b-c, where b is the maximum 
#'   fibril length.
#' @param lambda The stretch acting on the tissue.
#'
#' @return
#' A number, corresponding to the Cauchy stress acting on the collagen
#' fibrils.
#' @export
#'
#' @examples
#' rcpp_calc_gt_fib_cstress1(6, -3, -3, -3, 1.07)
rcpp_calc_gt_fib_cstress1 <- function(eta, tau, xi, chi, lambda) {
    .Call(`_TendonMCMCSampling_rcpp_calc_gt_fib_cstress1`, eta, tau, xi, chi, lambda)
}

#' Second function for the stress on the collagen fibrils (general tri. dist.)
#'
#' @description
#' Function that calculates the contribution to the Cauchy stress from the
#' collagen fibrils when the stretch is greater than the mode, c, but less 
#' than or equal to b, the maximum fibril length.
#'
#' @param eta The natural logarithm of phi*E, where E is the Young's modulus
#'   of the collagen fibrils and phi is the collagen fibril volume fraction.
#' @param tau The natural logarithm of a-1, where a is the minimum collagen
#'   fibril length.
#' @param xi The natural logarithm of c-a.
#' @param chi The natural logarithm of b-c.
#' @param lambda The stretch acting on the tissue.
#'
#' @return
#' A number, corresponding to the Cauchy stress acting on the collagen
#' fibrils.
#' @export
#'
#' @examples
#' rcpp_calc_gt_fib_cstress2(6, -3, -3, -3, 1.12)
rcpp_calc_gt_fib_cstress2 <- function(eta, tau, xi, chi, lambda) {
    .Call(`_TendonMCMCSampling_rcpp_calc_gt_fib_cstress2`, eta, tau, xi, chi, lambda)
}

#' Third function for the stress on the collagen fibrils (general tri. dist.)
#'
#' @description
#' Function that calculates the contribution to the Cauchy stress from the
#' collagen fibrils when the stretch is greater than b, the maximum collagen
#' fibril length.
#'
#' @param eta The natural logarithm of phi*E, where E is the Young's modulus
#'   of the collagen fibrils and phi is the collagen fibril volume fraction.
#' @param tau The natural logarithm of a-1, where a is the minimum length of 
#'   the collagen fibrils.
#' @param xi The natural logarithm of c-a, where c is the modal length of the
#'   collagen fibrils.
#' @param chi The natural logarithm of b-c.
#' @param lambda The stretch acting on the tissue.
#'
#' @return
#' A number, corresponding to the Cauchy stress acting on the collagen
#' fibrils.
#' @export
#'
#' @examples
#' rcpp_calc_gt_fib_cstress3(6, -3, -3, -3, 1.2)
rcpp_calc_gt_fib_cstress3 <- function(eta, tau, xi, chi, lambda) {
    .Call(`_TendonMCMCSampling_rcpp_calc_gt_fib_cstress3`, eta, tau, xi, chi, lambda)
}

#' Computes collagen fibril stress for a set of stretches (general tri. dist.)
#'
#' @description
#' Function that first determines which expression must be evaluated to 
#' calculate the stress acting on the fibrils at a given stretch. The function
#' also evaluates the stress, for a given parameter vector, at a vector of 
#' stretch values.  
#'
#' @param eta The natural logarithm of phi*E, where E is the Young's modulus
#'   of the collagen fibrils and phi is the collagen fibril volume fraction.
#' @param tau The natural logarithm of a-1, where a is the minimum collagen
#'   fibril length.
#' @param xi The natural logarithm of c-a, where c is the modal collagen fibril
#'   length.
#' @param chi The natural logarithm of b-c, where b is the maximum collagen
#'   fibril length.
#' @param lambda The vector of stretches that act on the tissue.
#'
#' @return
#' A vector, corresponding to the Cauchy stress acting on the collagen
#' fibrils at each stretch.
#' @export
#'
#' @examples
#' rcpp_calc_gt_fib_cstress(6, -3, -3, -3, c(1.06, 1.1, 1.2, 1.3))
rcpp_calc_gt_fib_cstress <- function(eta, tau, xi, chi, lambda) {
    .Call(`_TendonMCMCSampling_rcpp_calc_gt_fib_cstress`, eta, tau, xi, chi, lambda)
}

#' Computes tissue Cauchy stress for a set of stretches (general tri. dist.)
#'
#' @param nu The natural logarithm of (1-phi)*mu, where mu is the shear modulus
#'   of the non-collagenous matrix (NCM) and (1-phi) is the volume fraction
#'   of the NCM in the tissue.
#' @param eta The natural logarithm of phi*E, where E is the Young's modulus
#'   of the collagen fibrils and phi is the collagen fibril volume fraction.
#' @param tau The natural logarithm of a-1, where a is the minimum collagen
#'   fibril length.
#' @param xi The natural logarithm of c-a, where c is the modal collagen fibril
#'   length.
#' @param chi The natural logarithm of b-c, where b is the maximum collagen
#'   fibril length.
#' @param lambda The vector of stretches acting on the tissue.
#'
#' @return
#' A vector, corresponding to the Cauchy stress acting on the tissue at each
#' stretch measured.
#' @export
#'
#' @examples
#' rcpp_calc_gt_tot_cstress(1, 6, -3, -3, -3, c(1.08, 1.10, 1.2, 1.25, 1.3))
rcpp_calc_gt_tot_cstress <- function(nu, eta, tau, xi, chi, lambda) {
    .Call(`_TendonMCMCSampling_rcpp_calc_gt_tot_cstress`, nu, eta, tau, xi, chi, lambda)
}

#' Computes tissue engineering stress for a set of stretches (gen. tri. dist.)
#'
#' @param nu The natural logarithm of (1-phi)*mu, where mu is the shear modulus
#'   of the non-collagenous matrix (NCM) and (1-phi) is the volume fraction
#'   of the NCM in the tissue.
#' @param eta The natural logarithm of phi*E, where E is the Young's modulus
#'   of the collagen fibrils and phi is the collagen fibril volume fraction.
#' @param tau The natural logarithm of a-1, where a is the minimum collagen
#'   fibril length.
#' @param xi The natural logarithm of c-a, where c is the modal collagen fibril
#'   length.
#' @param chi The natural logarithm of b-c, where b is the maximum collagen
#'   fibril length.
#' @param lambda The vector of stretches acting on the tissue.
#'
#' @return
#' A vector, corresponding to the engineering stress acting on the collagen
#' fibrils at each stretch.
#' @export
#'
#' @examples
#' rcpp_calc_gt_tot_1pkstress(1, 6, -3, -3, -3, c(1.08, 1.1, 1.2, 1.25, 1.3))
rcpp_calc_gt_tot_1pkstress <- function(nu, eta, tau, xi, chi, lambda) {
    .Call(`_TendonMCMCSampling_rcpp_calc_gt_tot_1pkstress`, nu, eta, tau, xi, chi, lambda)
}

#' Calculate logarithms of the model parameters
#'
#' @param true_params A vector of, in order, (1-phi)*mu, phi*E, a-1, b-a.
#'
#' @return A vector with the logarithms of the model parameters.
#' @export
#'
#' @examples
#' rcpp_transf_true_params(c(5, 600, 0.02, 0.08))
rcpp_transf_true_params <- function(true_params) {
    .Call(`_TendonMCMCSampling_rcpp_transf_true_params`, true_params)
}

#' Calculate the model parameters from their logarithms
#'
#' @description
#' This function takes the logarithms of the four model parameters and creates
#' the following six-element vector:
#' \itemize{
#' \item elements 1-4 contain the model parameters.
#' \item element 5 is the minimal recruitment stretch, a.
#' \item element 6 is the maximal recruitment stretch, b.
#' }
#'
#' @param log_params A vector of, in order, nu, eta, tau, rho.
#'
#' @return A vector containing six elements that correspond to the four 
#'   fit parameters used in the RWM algorithm and the second distribution 
#'   parameters. (See the description above for more details.)
#' @export
#'
#' @examples
#' rcpp_transf_log_params(c(1.61, 6.40, -3.91, -2.53))
rcpp_transf_log_params <- function(log_params) {
    .Call(`_TendonMCMCSampling_rcpp_transf_log_params`, log_params)
}

#' Calculate prior ratio between two parameter vectors
#'
#' @description
#' This function calculates the prior probability of both the proposed
#' parameter vector and the current position of the Markov
#' chains. The ratio of the probabilities is then taken.
#' @param prop_params Proposed parameter values.
#' @param curr_params Current position of the Markov chains.
#' @param mean_vec Means of the normal prior distributions.
#' @param sd_vec Standard deviations of the normal priors.
#'
#' @return A number, the prior probability ratio.
#'
#' @examples
#' rcpp_compute_prior_ratio(c(0.1, 6), c(0.2, 5.5), c(0.5, 7), c(0.2, 0.4))
rcpp_compute_prior_ratio <- function(prop_params, curr_params, mean_vec, sd_vec) {
    .Call(`_TendonMCMCSampling_rcpp_compute_prior_ratio`, prop_params, curr_params, mean_vec, sd_vec)
}

#' A multivariate Student's t distribution coded in C++
#'
#' @description
#' This function calculates the log-probability of obtaining the experimental
#' stresses according to a Student's t distribution with mean values given
#' by the predicted stresses of the model.
#' @param obs_vec Experimental stresses.
#' @param mu_vec Predicted stresses.
#' @param scale_mat A scale matrix for this multivariate distribution.
#' @param nu The number of degrees of freedom.
#'
#' @return A number, the probability for the vector obs_vec.
rcpp_compute_dmvt <- function(obs_vec, mu_vec, scale_mat, nu) {
    .Call(`_TendonMCMCSampling_rcpp_compute_dmvt`, obs_vec, mu_vec, scale_mat, nu)
}

#' Calculate posterior-predictive ratio between two sets of predicted stresses
#'
#' @description
#' This function calculates the posterior-predictive of the stresses found by
#' inputting the proposed parameter vector into the model and the current 
#' position of the Markov chains into the model.
#' @param expt_data The experimental stresses we fit to.
#' @param prop_sim_data The proposed predicted stresses.
#' @param curr_sim_data The current predicted stresses.
#' @param alpha The first hyperparameter of the hyperprior on the 
#'   noise variance.
#' @param beta The second hyperparameter of the hyperprior on the 
#'   noise variance.
#' @param prop_true_params The proposed values of the untransformed parameters.
#' @param curr_true_params The current values of the untransformed parameters.
#'
#' @return
#' A vector containing the posterior-predictive ratio, as well as the value of 
#' the posterior-predictive for the proposed parameter vector and the current 
#' position of the Markov chains.
rcpp_calc_post_pred_rat <- function(expt_data, prop_sim_data, curr_sim_data, alpha, beta, prop_true_params, curr_true_params) {
    .Call(`_TendonMCMCSampling_rcpp_calc_post_pred_rat`, expt_data, prop_sim_data, curr_sim_data, alpha, beta, prop_true_params, curr_true_params)
}

#' Calculate the transition probability ratio
#'
#' @param prop_params Proposed parameter values.
#' @param curr_params Current position of the Markov chains.
#' @param mean_vec Means of the normal prior distributions.
#' @param sd_vec Standard deviations of the normal priors.
#' @param expt_data The experimental stresses we fit to.
#' @param prop_sim_data The proposed predicted stresses.
#' @param curr_sim_data The current predicted stresses.
#' @param alpha The first hyperparameter of the hyperprior on the 
#'   noise variance.
#' @param beta The second hyperparameter of the hyperprior on the 
#'   noise variance.
#' @param prop_true_params The proposed values of the untransformed parameters.
#' @param curr_true_params The current values of the untransformed parameters.
#'
#' @return
#' A vector containing the transition and prior probability ratios and the
#' likelihood ratio.
rcpp_compute_trans_prob <- function(prop_params, curr_params, mean_vec, sd_vec, expt_data, prop_sim_data, curr_sim_data, alpha, beta, prop_true_params, curr_true_params) {
    .Call(`_TendonMCMCSampling_rcpp_compute_trans_prob`, prop_params, curr_params, mean_vec, sd_vec, expt_data, prop_sim_data, curr_sim_data, alpha, beta, prop_true_params, curr_true_params)
}

#' Run RWM MCMC for the symmetric triangular distribution
#'
#' @param stretch_expt The experimental stretch ratios.
#' @param stress_expt The experimentally observed engineering stress values,
#'   in megapascals.
#' @param starting_values The starting values of the parameters (1-phi)*mu, 
#'   phi*\emph{E}, \emph{a}-1, and \emph{b}-\emph{a}.
#' @param mean_vec A vector of means for the normal prior distributions of the
#'   transformed parameters.
#' @param sd_vec A vector of the standard deviations for the normal prior
#'   distributions of the transformed parameters.
#' @param param_num The number of fit parameters.
#' @param block_length An integer that represents the number of simulations
#'   that make up one block in the algorithm.
#' @param burn_in_length An integer that represents the number of simulations
#'   performed in the burn-in phase.
#' @param sim_num An integer that signifies the total number of simulations
#'   performed in the algorithm.
#' @param scale_cov_factor A double corresponding to the scale factor, beta,
#'   used in the adaptation of the proposal distribution covariance matrix.
#' @param accept_range A vector containing the minimum and maximum acceptance
#'   rates that are deemed to be acceptable for the efficient running of the 
#'   algorithm.
#' @param alpha_hyp A double corresponding to the parameter alpha of the 
#'   hyperprior.
#' @param beta_hyp A double corresponding to the parameter beta of the 
#'   hyperprior.
#' @param cov_calc_num An integer that defines how many simulations we take 
#'   the results from to adapt the covariance matrix of the proposal 
#'   distribution in the burn-in phase. We always take the most recent 
#'   \emph{N} simulations.
#' @param cov_calc_some A Boolean that determines whether we use the results
#'   of all previous simulations or not when adapting the covariance matrix of 
#'   the proposal distribution in the burn-in phase.
#' @param change_cov_mat A Boolean that determines whether we change the 
#'   covariance matrix of the proposal distribution or not.
#' @param print_iter An integer that determines after how many simulations do
#'   we print the simulation number to the console (to show the progress of 
#'   the algorithm).
#' @param fit_vec_num An integer that determines how many parameter vectors we
#'   collect in a matrix that collates the parameter vectors that achieve the
#'   best fit to data. The fit to data is determined in terms of the average
#'   relative error between the predicted stress and the experimental stress.
#'
#' @return
#' A list containing the following terms:
#' 
#'  \itemize{
#'    \item a matrix with the transformed parameters found in the algorithm.
#'    \item a matrix with the untransformed parameter found in the algorithm
#'      and the average relative error obtained at the end of each iteration
#'      of the algorithm.
#'    \item a vector of the acceptance ratios in each block.
#'    \item the covariance matrix of the proposal distribution.
#'    \item the matrix of closest fits achieved in the algorithm.
#' }
rcpp_st_run_mcmc <- function(stretch_expt, stress_expt, starting_values, mean_vec, sd_vec, param_num, block_length, burn_in_length, sim_num, scale_cov_factor, accept_range, alpha_hyp, beta_hyp, cov_calc_num, cov_calc_some, change_cov_mat, print_iter, fit_vec_num) {
    .Call(`_TendonMCMCSampling_rcpp_st_run_mcmc`, stretch_expt, stress_expt, starting_values, mean_vec, sd_vec, param_num, block_length, burn_in_length, sim_num, scale_cov_factor, accept_range, alpha_hyp, beta_hyp, cov_calc_num, cov_calc_some, change_cov_mat, print_iter, fit_vec_num)
}

#' Calculates the Cauchy stress of the non-collagenous matrix (NCM)
#'
#' @param nu The natural logarithm of (1-phi)*mu.
#' @param lambda A vector of tissue stretches.
#'
#' @return
#' A vector, corresponding to the Cauchy stress acting on the NCM at each
#' stretch.
#' @export
#'
#' @examples
#' rcpp_calc_ncm_cstress(1, c(1.05, 1.1, 1.15, 1.2))
rcpp_calc_ncm_cstress <- function(nu, lambda) {
    .Call(`_TendonMCMCSampling_rcpp_calc_ncm_cstress`, nu, lambda)
}

#' First function that calculates the Cauchy stress of the collagen fibrils
#'
#' @description
#' Function that calculates the contribution to the Cauchy stress from the
#' collagen fibrils when the stretch is greater than a and less than or equal
#' to the mode, which lies half-way between a and b.
#'
#' @param eta The natural logarithm of phi*E.
#' @param tau The natural logarithm of a-1.
#' @param lambda The stretch acting on the tissue.
#'
#' @return
#' A number, corresponding to the Cauchy stress acting on the collagen
#' fibrils.
#' @export
#'
#' @examples
#' rcpp_calc_st_fib_cstress1(6, -3, 1.2)
rcpp_calc_st_fib_cstress1 <- function(eta, tau, lambda) {
    .Call(`_TendonMCMCSampling_rcpp_calc_st_fib_cstress1`, eta, tau, lambda)
}

#' Second function that calculates the Cauchy stress of the collagen fibrils
#'
#' @description
#' Function that calculates the contribution to the Cauchy stress from the
#' collagen fibrils when the stretch is greater than the mode, which lies
#' half-way between a and b, but less than or equal to b.
#'
#' @param eta The natural logarithm of phi*E.
#' @param tau The natural logarithm of a-1.
#' @param rho The natural logarithm of b-a.
#' @param lambda The stretch acting on the tissue.
#'
#' @return
#' A number, corresponding to the Cauchy stress acting on the collagen
#' fibrils.
#' @export
#'
#' @examples
#' rcpp_calc_st_fib_cstress2(6, -3, -2, 1.2)
rcpp_calc_st_fib_cstress2 <- function(eta, tau, rho, lambda) {
    .Call(`_TendonMCMCSampling_rcpp_calc_st_fib_cstress2`, eta, tau, rho, lambda)
}

#' Third function that calculates the Cauchy stress of the collagen fibrils
#'
#' @description
#' Function that calculates the contribution to the Cauchy stress from the
#' collagen fibrils when the stretch is greater than b.
#'
#' @param eta The natural logarithm of phi*E.
#' @param tau The natural logarithm of a-1.
#' @param rho The natural logarithm of b-a.
#' @param lambda The stretch acting on the tissue.
#'
#' @return
#' A number, corresponding to the Cauchy stress acting on the collagen
#' fibrils.
#' @export
#'
#' @examples
#' rcpp_calc_st_fib_cstress3(6, -3, -2, 1.2)
rcpp_calc_st_fib_cstress3 <- function(eta, tau, rho, lambda) {
    .Call(`_TendonMCMCSampling_rcpp_calc_st_fib_cstress3`, eta, tau, rho, lambda)
}

#' Calculates the Cauchy stress of the collagen fibrils for a set of stretches
#'
#' @description
#' Function that determines which expression must be evaluated to calculate
#' the stress acting on the fibrils at a given stretch, and which evaluates
#' each function for a vector of stretch values.
#'
#' @param eta The natural logarithm of phi*E.
#' @param tau The natural logarithm of a-1.
#' @param rho The natural logarithm of b-a.
#' @param lambda The vector of stretches that act on the tissue.
#'
#' @return
#' A vector, corresponding to the Cauchy stress acting on the collagen
#' fibrils at each stretch.
#' @export
#'
#' @examples
#' rcpp_calc_st_fib_cstress(6, -3, -2, c(1.1, 1.2, 1.3))
rcpp_calc_st_fib_cstress <- function(eta, tau, rho, lambda) {
    .Call(`_TendonMCMCSampling_rcpp_calc_st_fib_cstress`, eta, tau, rho, lambda)
}

#' Calculates the Cauchy stress of a tissue for a vector of stretches
#'
#' @param nu The natural logarithm of (1-phi)*mu.
#' @param eta The natural logarithm of phi*E.
#' @param tau The natural logarithm of a-1.
#' @param rho The natural logarithm of b-a.
#' @param lambda The vector of stretches acting on the tissue.
#'
#' @return
#' A vector, corresponding to the Cauchy stress acting on the tissue at each
#' stretch measured.
#' @export
#'
#' @examples
#' rcpp_calc_st_tot_cstress(1, 6, -3, -2, c(1.2, 1.25, 1.3))
rcpp_calc_st_tot_cstress <- function(nu, eta, tau, rho, lambda) {
    .Call(`_TendonMCMCSampling_rcpp_calc_st_tot_cstress`, nu, eta, tau, rho, lambda)
}

#' Calculates the engineering stress of a tissue for a vector of stretches
#'
#' @param nu The natural logarithm of (1-phi)*mu.
#' @param eta The natural logarithm of phi*E.
#' @param tau The natural logarithm of a-1.
#' @param rho The natural logarithm of b-a.
#' @param lambda The vector of stretches acting on the tissue.
#'
#' @return
#' A vector, corresponding to the Cauchy stress acting on the collagen
#' fibrils at each stretch.
#' @export
#'
#' @examples
#' rcpp_calc_st_tot_1pkstress(1, 6, -3, -2, c(1.2, 1.25, 1.3))
rcpp_calc_st_tot_1pkstress <- function(nu, eta, tau, rho, lambda) {
    .Call(`_TendonMCMCSampling_rcpp_calc_st_tot_1pkstress`, nu, eta, tau, rho, lambda)
}

