#' Calculate average relative error between experimental and predicted stresses
#' 
#' This function calculates the average relative error between the experimental
#' data and the stresses predicted by the model for a given parameter vector.
#' For each experimental data set, the first stretch ratio measured is one, 
#' which gives a stress of zero. By construction of the model, the stress when 
#' the stretch ratio is one is zero. Therefore, we do not include the first term 
#' of the experimental or predicted stresses for this calculation.
#'
#' @param expt_data The experimental stresses we fit to.
#' @param prop_sim_data The proposed predicted stresses.
#'
#' @return
#' A number with the average relative error between the experimental stresses
#' and the predicted stresses.
#' @export
compute_ave_rel_err <- function(expt_data,
                                prop_sim_data) {
  k <- length(expt_data)
  prelim1 <- abs(expt_data[2:k] - prop_sim_data[2:k])
  prelim2 <- prelim1 / abs(expt_data[2:k])

  sum(prelim2) / (k - 1)
}