library(tidyverse)
library(extrafont)
library(miceadds)

# The plotting functions use the font Latin Modern Roman (LMR). This font may
# need to be downloaded to your computer and then added to RStudio or another
# program that this script is run in. To add the LMR font to RStudio, for 
# example, follow these instructions. Download the .ttf file for LMR, from
# http://www.fontsquirrel.com/fonts/latin-modern-roman and save the file in the
# directory where your fonts are stored. Then, in Windows, the following code
# added LMR as a font to RStudio. 
#
# font_export()
# loadfonts(device = "win")
#
# An error may occur in font_export() with the error message 'No FontName.
# Skipping'. If that occurs, a workaround is to execute the following code
#
# library(remotes)
# remotes::install_version("Rttf2pt1", version = "1.3.8")
# library(extrafont)
# loadfonts(device = "win")
# fonts()

# After loading fonts for the first time, they can be loaded using loadfonts().
loadfonts()
print('new')
data_file <- h16_data

expt_strain_plot <- data_file[, "Stretch"]
expt_stress_plot <- data_file[, "Stress"]

l_cdf_values     = c(0.001, 3.072, 0.005, 0.005, 0.005)
u_cdf_values     = c(10, 13600, 0.10, 0.15, 0.15)
l_quantile       = 0.01
u_quantile       = 0.99

prior_param_list <- compute_prior_params(l_cdf_values,
                                         u_cdf_values,
                                         l_quantile,
                                         u_quantile)

means_vec <- prior_param_list[[1]]
sds_vec <- prior_param_list[[2]]

return_list1 <- rcpp_gt_run_mcmc(stretch_expt = expt_strain_plot,
                                 stress_expt = expt_stress_plot,
                                 starting_values = c(1, 500, 0.03, 0.05, 0.1),
                                 mean_vec = means_vec,
                                 sd_vec = sds_vec,
                                 param_num = 5,
                                 block_length = 500,
                                 burn_in_length = 500000,
                                 sim_num = 1500001,
                                 scale_cov_factor = 0.95,
                                 accept_range = c(0.184, 0.284),
                                 alpha_hyp = 3.0,
                                 beta_hyp = 0.3,
                                 cov_calc_num = 10000,
                                 cov_calc_some = TRUE,
                                 change_cov_mat = TRUE,
                                 print_iter = 10000,
                                 fit_vec_num = 10)

logparam_list  <- return_list1[[1]]
trueparam_list <- return_list1[[2]]
acceptrat_list <- return_list1[[3]]
sigma_cov_mat  <- return_list1[[4]]
bestfits_list  <- return_list1[[5]]

logparam_list <- logparam_list[500002:1500001, ]
trueparam_list <- trueparam_list[500002:1500001, ]

logparam_df <- as.data.frame(logparam_list)
trueparam_df <- as.data.frame(trueparam_list)

logparam_df <- setNames(logparam_df, c("Nu", "Eta", "Tau", "Xi", "Chi"))
trueparam_df <- setNames(trueparam_df, c("ShearMod", "YoungsMod", "a-1", 
                                         "c-a", "b-c", "a",
                                         "c", "b", "Ave. error"))

# We thin the samples from the algorithm in order to use in the plotting 
# function plot_corr.

thinning_vec <- seq(from = 1, 
                    to   = length(trueparam_list[, 1]),
                    by   = 10)

thinned_log_mat  <- logparam_list[thinning_vec, ]
thinned_true_mat <- trueparam_list[thinning_vec, ]

thinned_length <- length(thinned_log_mat[, 3])
full_length    <- length(trueparam_list[, 3])

thinned_log_df <- as.data.frame(thinned_log_mat)
thinned_true_df <- as.data.frame(thinned_true_mat)

thinned_log_df <- setNames(thinned_log_df, c("Nu", "Eta", "Tau", "Xi", "Chi"))
thinned_true_df <- setNames(thinned_true_df, c("ShearMod", "YoungsMod", "a-1", 
                                               "c-a", "b-c", "a",
                                               "c", "b", "Ave. error"))

# We create a directory to store plots and any data frame, matrices, or vectors
# that we wish to keep.
# 
main_dir <- "Tests"
dir.create(main_dir)
setwd(main_dir)

# Create a sub-directory specifically for the ggplot matrix.
# if(file.exists(sub_dir_ggmat) == FALSE){
  #  dir.create(sub_dir_ggmat)
# }
# dir_plots_ggmat <- paste0(main_dir, "/", sub_dir_ggmat)
# setwd(dir_plots_ggmat)

labels_vec <- c('(1 - phi) * mu ~ " (MPa)"',
                "phi * italic(E) ~ ' (MPa)'",
                "italic(a)",
                "italic(c)",
                "italic(b)")

ggmat1 <- plot_corr_gt(df = thinned_true_df,
                       vec_rows = c(1, thinned_length),
                       vec_cols = c(1, 2, 6, 7, 8),
                       pos_values_pc = 95, #99.5,
                       cov_values_pc = 95, #98,
                       dps_vec = c(2, 0, 4, 3, 3),
                       parsed_labels_vec = labels_vec,
                       x_strip_font_size = 10,
                       y_strip_font_size = 8,
                       pic_width = 17.4,
                       aspect_ratio = 1.36,
                       pic_units = "cm",
                       save_plot = TRUE,
                       save_title = "h16SDFT_gt_trueparams_ggmatrix",
                       image_type = "pdf")

# Create a sub-directory specifically for the mean and confidence band plots.
# if(file.exists(sub_dir_mean) == FALSE){
#   dir.create(sub_dir_mean)
# }
# dir_plots_mean <- paste0(main_dir, "/", sub_dir_mean)
# setwd(dir_plots_mean)

save_title_macb <- paste0("h16SDFT_gt_MACBPlot")
y_label_macb    <- paste0("italic(N) ~ ' (MPa)'")
x_label_macb    <- paste0("lambda")

set.seed(64)
# plot showing the model fit ith 95CI and zoomed in panel
plot_MACB_gt(param_values_df = trueparam_df,
             param_vec_num   = 50000,
             cols_sampled    = c(1, 2, 3, 4, 5),
             sigma_num       = 5,
             strain_expt     = expt_strain_plot,
             stress_expt     = expt_stress_plot,
             save_title      = save_title_macb,
             x_label         = x_label_macb,
             y_label         = y_label_macb,
             image_type      = "pdf",
             pic_width       = 17.4,
             aspect_ratio    = 1.86,
             pic_units       = "cm",
             zoom_x_min      = 1.075,
             zoom_x_max      = max(expt_strain_plot),
             log_params      = FALSE)

cred_95pc_trueParams <- compute_cred_int(trueparam_df, 95)
cred_95pc_logParams  <- compute_cred_int(logparam_df, 95)

# setwd(main_dir)

write.csv(cred_95pc_trueParams, "h16SDFT_gt_trueparams_95pcCI.csv")
write.csv(cred_95pc_logParams, "h16SDFT_gt_logparams_95pcCI.csv")

write.csv(trueparam_df[seq(999001, 1000000), ], 
          "h16SDFT_gt_trueparam_last10k.csv")
# jess adding in 
write.table(trueparam_df, "h16SDFT_gt_trueparam_all.txt")
write.csv(acceptrat_list, "h16SDFT_gt_accept_ratios.csv")
write.csv(sigma_cov_mat, "h16SDFT_gt_sigma_cov_mat.csv")
write.csv(bestfits_list, "h16SDFT_gt_bestfits.csv")

savetitle1 <- paste0("h16SDFT_gt_dens_hist_unnorm")
savetitle2 <- paste0("h16SDFT_gt_dens_hist_norm")

# Create two histograms. One histogram plots 2c - b - a on the x-axis and the 
# other plots 2c - b - a/(b - a) on the x-axis. These are referred to as the
# 'unnormalised' and 'normalised' histograms in the titles that they are saved
# under.

savetitle1 <- paste0("h16SDFT_gt_density_histogram_unnorm")
savetitle2 <- paste0("h16SDFT_gt_density_histogram_norm")

xticks_vec <- c(0.6, 0.7, 0.8, 0.9)
yticks_vec <- c(0, 2, 4, 6)

hist_vec <- plot_distparam_hist_density(df = trueparam_df,
                                        min_rs_col = 6,
                                        modal_rs_col = 7,
                                        max_rs_col = 8,
                                        pic_width = 8.55,
                                        aspect_ratio = 1.618,
                                        savetitle_unnorm = savetitle1,
                                        savetitle_norm = savetitle2,
                                        pic_units = "cm",
                                        binnum_unnorm = 50,
                                        binnum_norm = 50,
                                        xlabel_unnorm = "Value",
                                        xlabel_norm = "Value",
                                        xticks = xticks_vec,
                                        yticks = yticks_vec,
                                        title_size = 12,
                                        image_type = "pdf")