% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gt_plotting_functions.R
\name{plot_MACB_gt}
\alias{plot_MACB_gt}
\title{Plot mean stresses and a confidence band around the means}
\usage{
plot_MACB_gt(
  param_values_df,
  param_vec_num,
  cols_sampled,
  sigma_num,
  strain_expt,
  stress_expt,
  save_title,
  x_label,
  y_label,
  image_type,
  pic_width,
  aspect_ratio,
  pic_units = "cm",
  zoom_x_min = 1,
  zoom_x_max = max(strain_expt),
  log_params = FALSE
)
}
\arguments{
\item{param_values_df}{Matrix of parameter values found by the Markov chains.}

\item{param_vec_num}{Number of parameter vectors, i.e. rows of
\code{param_values_df}, that are selected.}

\item{cols_sampled}{Columns of \code{param_values_df} that are selected.}

\item{sigma_num}{How many sigma away from the mean does the confidence band
extend.}

\item{strain_expt}{Vector of experimentally observed stretches.}

\item{stress_expt}{Vector of experimentally observed stresses.}

\item{save_title}{Title that the plots are saved under.}

\item{x_label}{Label along the x-axis of the plot.}

\item{y_label}{Label along the y-axis of the plot.}

\item{image_type}{String containing the image format that the plot is saved
under, e.g. .jpg or .pdf.}

\item{pic_width}{Width of the plot.}

\item{aspect_ratio}{Aspect ratio of the plot.}

\item{pic_units}{String containing the units that the picture dimensions
are calculated in, e.g. cm.}

\item{zoom_x_min}{Minimum stretch that we zoom-in on.}

\item{zoom_x_max}{Maximum stretch that we zoom-in on.}

\item{log_params}{A Boolean on whether \code{param_values_df} contains the
transformed parameter values or not.}
}
\value{
Void
}
\description{
This function first takes a randomly selected subset of positions from the
Markov chains, with the size of the subset determined by the user. It then
calculates the mean and variance of the stresses, at each stretch given in
the experimental data, predicted by the chosen parameter vectors. The
function then plots the mean and a confidence band corresponding to a
particular multiple of the variance around the mean values. The experimental
stress-strain values are also plotted. Finally, the function zooms in on a
particular part of the x-axis to make the various elements of the plot more
visible for a section of the stress-strain curve.
}
