% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gt_plotting_functions.R
\name{plot_corr_gt}
\alias{plot_corr_gt}
\title{Plot marginals and 2D contour plots from a data frame of parameter values}
\usage{
plot_corr_gt(
  df,
  vec_rows,
  vec_cols,
  pos_values_pc,
  cov_values_pc,
  dps_vec,
  parsed_labels_vec,
  x_strip_font_size,
  y_strip_font_size,
  pic_width = 17.4,
  aspect_ratio = 1.36,
  pic_units = "cm",
  save_plot = TRUE,
  save_title = NA,
  image_type = NA
)
}
\arguments{
\item{df}{Data frame of parameter values.}

\item{vec_rows}{Vector with the first and last row of \code{df} to use to
estimate marginal posteriors and 2D contours.}

\item{vec_cols}{Columns of \code{df} that are used.}

\item{pos_values_pc}{A float that defines the percentage of parameter values
that are shown on the marginal posteriors. E.g. 99 would indicate that we
zoom-in on the marginal posterior, with the limits given by the values at
0.5% and 99.5% cumulative distribution. Note that all values in \code{df}
are used to calculate the marginals and 2D contour plots.}

\item{cov_values_pc}{A float that defines which values from the
bottom and top of the cumulative distribution are used to define the
visible limits of the y-axis of the contour plots.}

\item{dps_vec}{Vector of decimal places that ticks are given to for each
parameter.}

\item{parsed_labels_vec}{A vector of strings corresponding to the labels
of the strips on the ggplot matrix. Note that these strings are parsed in
the function.}

\item{x_strip_font_size}{The size of the font for the strips along the
x-axis.}

\item{y_strip_font_size}{The size of the font for the strips along the
y-axis.}

\item{pic_width}{Width of the plot.}

\item{aspect_ratio}{Aspect ratio of the plot.}

\item{pic_units}{String containing the units that the picture dimensions
are calculated in, e.g. cm.}

\item{save_plot}{A Boolean that determines whether the ggplot matrix is saved
or not.}

\item{save_title}{String containing the title that the plot matrix
is saved under.}

\item{image_type}{String containing the image format that the plot is saved
under, e.g. jpg or pdf.}
}
\value{
A square ggplot matrix object that contains marginal posteriors along
  the main diagonal, 2D contour plots between the parameters with one
  another on the lower triangle of the matrix, and correlations between the
  parameters with one another on the upper triangle of the matrix.
}
\description{
This function takes a data frame of parameter values and creates a ggplot
matrix that contains marginal posteriors of the parameters, and contour
plots and correlations between the parameters with one another. The function
also changes the limits of the marginal distributions and contour plots in
order to make the distribution and contour lines, respectively, more easily
observable.
}
