% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/RcppExports.R
\name{rcpp_st_run_mcmc}
\alias{rcpp_st_run_mcmc}
\title{Run RWM MCMC for the symmetric triangular distribution}
\usage{
rcpp_st_run_mcmc(
  stretch_expt,
  stress_expt,
  starting_values,
  mean_vec,
  sd_vec,
  param_num,
  block_length,
  burn_in_length,
  sim_num,
  scale_cov_factor,
  accept_range,
  alpha_hyp,
  beta_hyp,
  cov_calc_num,
  cov_calc_some,
  change_cov_mat,
  print_iter,
  fit_vec_num
)
}
\arguments{
\item{stretch_expt}{The experimental stretch ratios.}

\item{stress_expt}{The experimentally observed engineering stress values,
in megapascals.}

\item{starting_values}{The starting values of the parameters (1-phi)*mu, 
phi*\emph{E}, \emph{a}-1, and \emph{b}-\emph{a}.}

\item{mean_vec}{A vector of means for the normal prior distributions of the
transformed parameters.}

\item{sd_vec}{A vector of the standard deviations for the normal prior
distributions of the transformed parameters.}

\item{param_num}{The number of fit parameters.}

\item{block_length}{An integer that represents the number of simulations
that make up one block in the algorithm.}

\item{burn_in_length}{An integer that represents the number of simulations
performed in the burn-in phase.}

\item{sim_num}{An integer that signifies the total number of simulations
performed in the algorithm.}

\item{scale_cov_factor}{A double corresponding to the scale factor, beta,
used in the adaptation of the proposal distribution covariance matrix.}

\item{accept_range}{A vector containing the minimum and maximum acceptance
rates that are deemed to be acceptable for the efficient running of the 
algorithm.}

\item{alpha_hyp}{A double corresponding to the parameter alpha of the 
hyperprior.}

\item{beta_hyp}{A double corresponding to the parameter beta of the 
hyperprior.}

\item{cov_calc_num}{An integer that defines how many simulations we take 
the results from to adapt the covariance matrix of the proposal 
distribution in the burn-in phase. We always take the most recent 
\emph{N} simulations.}

\item{cov_calc_some}{A Boolean that determines whether we use the results
of all previous simulations or not when adapting the covariance matrix of 
the proposal distribution in the burn-in phase.}

\item{change_cov_mat}{A Boolean that determines whether we change the 
covariance matrix of the proposal distribution or not.}

\item{print_iter}{An integer that determines after how many simulations do
we print the simulation number to the console (to show the progress of 
the algorithm).}

\item{fit_vec_num}{An integer that determines how many parameter vectors we
collect in a matrix that collates the parameter vectors that achieve the
best fit to data. The fit to data is determined in terms of the average
relative error between the predicted stress and the experimental stress.}
}
\value{
A list containing the following terms:

 \itemize{
   \item a matrix with the transformed parameters found in the algorithm.
   \item a matrix with the untransformed parameter found in the algorithm
     and the average relative error obtained at the end of each iteration
     of the algorithm.
   \item a vector of the acceptance ratios in each block.
   \item the covariance matrix of the proposal distribution.
   \item the matrix of closest fits achieved in the algorithm.
}
}
\description{
Run RWM MCMC for the symmetric triangular distribution
}
