% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/run_rwm_mcmc.R
\name{run_rwm_mcmc}
\alias{run_rwm_mcmc}
\title{Run RWM MCMC for a given set of experimental stress-strain data}
\usage{
run_rwm_mcmc(
  strain_data,
  stress_data,
  starting_values,
  lower_cdf_values,
  upper_cdf_values,
  lower_cd,
  upper_cd,
  df_log_col_names,
  df_col_names,
  par_num = 4,
  block_length = 100,
  burn_in_length = 1e+05,
  sim_num = 1e+06,
  scale_cov_factor = 0.95,
  accept_range = c(0.184, 0.284),
  alpha_hyp = 3,
  beta_hyp = 0.3,
  cov_calc_num = 1e+05,
  cov_calc_some = FALSE,
  change_cov_mat = TRUE,
  print_iter = 10000,
  input_init_cov_mat = FALSE,
  init_cov_mat = diag(rep(1, par_num))/5,
  fit_vec_num = 5
)
}
\arguments{
\item{strain_data}{The experimental stretch values.}

\item{stress_data}{The experimental engineering stress values.}

\item{starting_values}{Initial guesses for the parameters.}

\item{lower_cdf_values}{Parameter values at which the lower cumulative
probability is reached.}

\item{upper_cdf_values}{Parameter values at which the higher cumulative
probability is reached.}

\item{lower_cd}{Lower cumulative distribution.}

\item{upper_cd}{Higher cumulative distribution.}

\item{df_log_col_names}{Names for the columns of the transformed parameter
data frame.}

\item{df_col_names}{Names for the columns of the untransformed parameter
data frame.}

\item{par_num}{Number of model parameters.}

\item{block_length}{Number of iterations per block.}

\item{burn_in_length}{Number of iterations in the burn-in phase.}

\item{sim_num}{Number of simulations.}

\item{scale_cov_factor}{Scaling factor for the proposal covariance matrix.}

\item{accept_range}{Lower and upper satisfactory acceptance rates.}

\item{alpha_hyp}{First parameter of the inverse-gamma hyperprior.}

\item{beta_hyp}{Second parameter of the inverse-gamma hyperprior.}

\item{cov_calc_num}{Number of previous iterations to use to calculate the
parameter covariances.}

\item{cov_calc_some}{Boolean determining whether only the last 
\code{cov_calc_num} iterations are used to calculate parameter covariances 
or whether all previous iterations are used.}

\item{change_cov_mat}{Boolean determining whether the proposal covariance
matrix is changed or not.}

\item{print_iter}{An integer that determines after how many iterations we
print the iteration number to the console.}

\item{input_init_cov_mat}{Boolean on whether a user-designated initial
covariance matrix is used or not.}

\item{init_cov_mat}{An initial covariance matrix.}

\item{fit_vec_num}{The number of closest fits that are retained in the
matrix of closest fits.}
}
\value{
A list containing the following terms:

 \itemize{
    \item a matrix with the transformed parameters found in the algorithm.
    \item a matrix with the untransformed parameter found in the algorithm
       and the average relative error obtained at the end of each iteration
       of the algorithm.
    \item a vector of the acceptance ratios in each block.
    \item the covariance matrix of the proposal distribution.
    \item the matrix of closest fits achieved in the algorithm.
}
}
\description{
Run RWM MCMC for a given set of experimental stress-strain data
}
