#include <iostream>
#include <vector>
#include <cmath>
#include "RCppArmadillo.h"
using namespace Rcpp;

//' Find the average relative error between experimental and predicted stresses
//' 
//' This function calculates the average relative error between the experimental
//' data and the stresses predicted by the model for a given parameter vector.
//' For each experimental data set, the first stretch ratio measured is one, 
//' which gives a stress of zero. By construction of the model, the stress when 
//' the stretch ratio is one is zero. Therefore, we do not include the first 
//' term of the experimental or predicted stresses for this calculation.
//'
//' @param expt_data The experimental stresses we fit to.
//' @param prop_sim_data The proposed predicted stresses.
//'
//' @return
//' A double with the average relative error between the experimental stresses
//' and the predicted stresses.
// [[Rcpp::export]]
double rcpp_calc_ave_rel_err(arma::vec expt_data,
                             arma::vec prop_sim_data) {
  int n = expt_data.n_elem;
  
  arma::vec ae_prelim1 = expt_data(arma::span(1, (n - 1)));
  arma::vec ae_prelim2 = prop_sim_data(arma::span(1, (n-1)));
  arma::vec ae_prelim3 = arma::abs(ae_prelim1 - ae_prelim2) / 
    arma::abs(ae_prelim1);
  
  double ave_rel_error = sum(ae_prelim3) / ae_prelim3.n_elem;
  
  return ave_rel_error;
}

