#include <iostream>
#include <vector>
#include <cmath>
#include "RCppArmadillo.h"
using namespace Rcpp;

// [[Rcpp::depends(RcppArmadillo)]]

//' Compute logarithms of the model parameters (general tri. dist.)
//'
//' @param true_params A vector of, in order, (1-phi)*mu, phi*E, a-1, c-a, b-c.
//'
//' @return A vector with the logarithms of the model parameters.
//' @export
//'
//' @examples
//' rcpp_transf_true_params_gt(c(5, 600, 0.02, 0.08, 0.1))
// [[Rcpp::export]]
arma::vec rcpp_transf_true_params_gt(arma::vec true_params) {
  return arma::log(true_params);
}


//' Compute the model parameters from their logarithms (general tri. dist.)
//'
//' @description
//' This function takes the logarithms of the five model parameters and creates
//' the following eight-element vector:
//' \itemize{
//' \item elements 1-5 contain the model parameters.
//' \item element 6 is the minimum recruitment stretch, or fibril length, a.
//' \item element 7 is the modal recruitment stretch, c.
//' \item element 8 is the maximum recruitment stretch, b.
//' }
//'
//' @param log_params A vector of, in order, nu, eta, tau, xi, chi.
//'
//' @return A vector containing eight elements that correspond to the five 
//'   fit parameters used in the RWM algorithm and the three distribution 
//'   parameters. (See the description above for more details.)
//' @export
//'
//' @examples
//' rcpp_transf_log_params_gt(c(1.61, 6.40, -3.91, -2.53, -2))
// [[Rcpp::export]]
arma::vec rcpp_transf_log_params_gt(arma::vec log_params) {
  int n  = log_params.n_elem;
  int n2 = n + 3;
  arma::vec result(n2, arma::fill::zeros);
  
  for(int i = 0; i < n; i++){
    result(i) = exp(log_params(i));
  }
  
  result(n) = result(n - 3) + 1.0;
  result(n + 1) = result(n - 3) + result(n - 2) + 1.0;
  result(n + 2) = result(n - 3) + result(n - 2) + result(n - 1) + 1.0;
  
  return result;
}
